@@ -28,12 +28,11 @@ perl -MDevel::Cover t/00_CappedCollection/10_quit.t
 perl -MDevel::Cover t/00_CappedCollection/11_max_datasize.t
 perl -MDevel::Cover t/00_CappedCollection/12_last_errorcode.t
 perl -MDevel::Cover t/00_CappedCollection/13_name.t
-perl -MDevel::Cover t/00_CappedCollection/14_size.t
 perl -MDevel::Cover t/00_CappedCollection/15_advance_cleanup_bytes.t
-perl -MDevel::Cover t/00_CappedCollection/16_big_data_threshold.t
 perl -MDevel::Cover t/00_CappedCollection/17_advance_cleanup_num.t
 perl -MDevel::Cover t/00_CappedCollection/18_info.t
 perl -MDevel::Cover t/00_CappedCollection/19_drop.t
+perl -MDevel::Cover t/00_CappedCollection/20_cleaning.t
 perl -MDevel::Cover xt/release/00_CappedCollection/98_pod.t
 perl -MDevel::Cover xt/release/00_CappedCollection/99_pod_coverage.t
 
